@@ -113,6 +113,7 @@ struct ZOOM_connection_p {
 
     int log_details;
     int log_api;
+    WRBUF saveAPDU_wrbuf;
 };
 
 #if ZOOM_RESULT_LISTS
@@ -283,6 +284,7 @@ void ZOOM_set_HTTP_error(ZOOM_connection c, int error,
 ZOOM_Event ZOOM_connection_get_event(ZOOM_connection c);
 void ZOOM_connection_remove_events(ZOOM_connection c);
 void ZOOM_Event_destroy(ZOOM_Event event);
+zoom_ret ZOOM_send_GDU(ZOOM_connection c, Z_GDU *gdu);
 
 /*
  * Local variables:
